// partition:  a container for organizing a set of sequential integers
//             into non-overlapping groups.
// Version:    %VERSION%
// Copyright:  2013 Matthew T. Busche.
//
// This program is free software:  you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation, either version 3 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along
// with this program.  If not, see <http://www.gnu.org/licenses/>.

package org.mattbusche.util.partition.examples;

import org.mattbusche.util.partition.*;
import java.util.Formatter;

/** A simple class to model the compound state of each crayon.
 **/
public class CrayonState {

    /** Each crayon can be in one of three User states:
     **    in the box,
     **    in use by Cate, or
     **    in use by Becky
     **/
    public enum User { BOX, CATE, BECKY; }

    /** To make things a little more interesting, we'll give each crayon
     ** a quality state as well:
     **/
    public enum Quality { SHARP, DULL; }

    public final User user;
    public final Quality quality;

    public CrayonState(User u, Quality q) {
        this.user    = u;
        this.quality = q;
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        Formatter formatter = new Formatter(sb);
        formatter.format("(%5s, %5s)", user.toString(), quality.toString());
        return formatter.toString();
    }
}
